# High-Level-Event-Mining: A Framework (ICPM 2022)

## Installation

```bash
pip install -r requirements.txt
```

## Usage

Save your event log in the same directory as `main.py` and name it `log.xes`. 
Alternatively, you can use the provided file which is the simulated log used in the paper.

To execute:
```bash
python main.py 
```
